Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1362)

Unified Diff: media/base/filter_host.h

Issue 18546: Implementation of Pipeline and FilterHost interfaces. This is a large change... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/factory.h ('k') | media/base/filter_host_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/filter_host.h
===================================================================
--- media/base/filter_host.h (revision 8731)
+++ media/base/filter_host.h (working copy)
@@ -43,8 +43,8 @@
// may call this method passing NULL for the callback argument.
//
// Callback arguments:
- // int64 the new pipeline time, in microseconds
- virtual void SetTimeUpdateCallback(Callback1<int64>::Type* callback) = 0;
+ // base::TimeDelta - the new pipeline time, in microseconds.
+ virtual void SetTimeUpdateCallback(Callback1<base::TimeDelta>::Type* cb) = 0;
// Filters must call this method to indicate that their initialization is
// complete. They may call this from within their Initialize() method or may
@@ -59,15 +59,15 @@
// Sets the current time. Any filters that have registered a callback through
// the SetTimeUpdateCallback method will be notified of the change.
- virtual void SetTime(int64 time) = 0;
+ virtual void SetTime(base::TimeDelta time) = 0;
// Get the duration of the media in microseconds. If the duration has not
// been determined yet, then returns 0.
- virtual void SetDuration(int64 duration) = 0;
+ virtual void SetDuration(base::TimeDelta duration) = 0;
// Set the approximate amount of playable data buffered so far in micro-
// seconds.
- virtual void SetBufferedTime(int64 buffered_time) = 0;
+ virtual void SetBufferedTime(base::TimeDelta buffered_time) = 0;
// Set the total size of the media file.
virtual void SetTotalBytes(int64 total_bytes) = 0;
@@ -80,7 +80,7 @@
virtual void SetVideoSize(size_t width, size_t height) = 0;
protected:
- virtual ~FilterHost() = 0;
+ virtual ~FilterHost() {}
};
} // namespace media
« no previous file with comments | « media/base/factory.h ('k') | media/base/filter_host_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698